﻿// ai_oneshot.cpp : 此文件包含 "main" 函数。程序执行将在此处开始并结束。
//
// 此例程是控制采集卡模拟输入通道单次采集，需要设定每次每通道采集点数。
// 此例程适用型号：
// PCI-225x

#include "pch.h"
#include <iostream>
#include "../../lib/spcidev.h"

int main()
{
	int rst;
	int i;
	int DevIndex = 0;
	float AiValue[8000];
	unsigned long AiFifoUsdw;

	// 打开设备
	rst = OpenDevice(DevIndex);
	if (rst < 0) { return rst; }
	
	// 设置 Ai 接线方式为 RSE
	rst = SetAiConnectType(DevIndex, 0);
	if (rst < 0) { return rst; }
	
	// 设置 Ai 采集通道选择
	// 此处选择 ai 0 ~ ai 7，一共 8 通道
	rst = SetAiChannelSellect(DevIndex, 0x00ff);
	
	// 设置 Ai 采集模式为 OneShot
	rst = SetAiSampleMode(DevIndex, 1);
	if (rst < 0) { return rst; }

	// 设置 Ai 采样周期，10000ns，即 100kS/s
	rst = SetAiSamplePeriod(DevIndex, 10000);
	if (rst < 0) { return rst; }

	// 设置 Ai 量程 1。
	// 对于 PCI-3000 系列，此处将通道 0 ~ 7 均设置为量程 1。
	// 对于 PCI-225x/5000 系列，不需要循环设置 8 次，1 次即可。
	for (i = 0; i < 8; i++)
	{
		rst = SetAiRange(DevIndex, 1, i);
		if (rst < 0) { return rst; }
	}
	
	// 设置 Ai OneShot 点数，每通道采集 1000 点
	rst = SetAiOneShotCount(DevIndex, 1000); 
	if (rst < 0) { return rst; }

	// 设置 Ai 触发源，Ai 软件触发
	rst = SetAiTrigSource(DevIndex, 0);
	if (rst < 0) { return rst; }

	// 设置 Ai 准备完成，AiReady
	rst = AiReady(DevIndex, 1);
	if (rst < 0) { return rst; }

	// 发出 Ai 软件触发命令
	rst = SetAiSoftTrig(DevIndex);
	if (rst < 0) { return rst; }

	// 读取 Ai OneShot 得到的数据
	// 此处每通道读取 1000 点，前面开启了 8 通道，一共 8000 点存放于 AiValue 中
	// AiValue[0] ~ AiValue[999] 是通道 ai 0 的数据
	// AiValue[1000] ~ AiValue[1999] 是通道 ai 1 的数据
	// AiValue[2000] ~ AiValue[2999] 是通道 ai 2 的数据
	// AiValue[3000] ~ AiValue[3999] 是通道 ai 3 的数据
	// AiValue[4000] ~ AiValue[4999] 是通道 ai 4 的数据
	// AiValue[5000] ~ AiValue[5999] 是通道 ai 5 的数据
	// AiValue[6000] ~ AiValue[6999] 是通道 ai 6 的数据
	// AiValue[7000] ~ AiValue[7999] 是通道 ai 7 的数据
	rst = GetAiData(DevIndex, 1000, AiValue, &AiFifoUsdw, 2000);
	if (rst < 0) { return rst; }

	printf("GetAiData Success.\n");

	// 清除 Ai 软件触发标志
	rst = ClearAiSoftTrig(DevIndex);
	if (rst < 0) { return rst; }

	// 清除 Ai 准备完成标志
	rst = AiReady(DevIndex, 0);
	if (rst < 0) { return rst; }

	// 关闭设备
	rst = CloseDevice(DevIndex);

	return rst;
}

// 运行程序: Ctrl + F5 或调试 >“开始执行(不调试)”菜单
// 调试程序: F5 或调试 >“开始调试”菜单

// 入门提示: 
//   1. 使用解决方案资源管理器窗口添加/管理文件
//   2. 使用团队资源管理器窗口连接到源代码管理
//   3. 使用输出窗口查看生成输出和其他消息
//   4. 使用错误列表窗口查看错误
//   5. 转到“项目”>“添加新项”以创建新的代码文件，或转到“项目”>“添加现有项”以将现有代码文件添加到项目
//   6. 将来，若要再次打开此项目，请转到“文件”>“打开”>“项目”并选择 .sln 文件
