﻿// ao_waveform_infinite_non_circulation.cpp : 此文件包含 "main" 函数。程序执行将在此处开始并结束。
//
// 此例程控制采集卡输出无限不循环的模拟任意波信号。
// 此例程适用型号：
// PCI-2253

#include "pch.h"
#include <Windows.h>
#include <iostream>
#include "../../lib/spcidev.h"

int main()
{
	int rst;
	int DevIndex = 0;
	int i, j;
	float WaveData;

	// 打开设备
	rst = OpenDevice(DevIndex);
	if (rst < 0) { return rst; }

	// 清空 Ao 0 波形 FIFO
	rst = ClearAoFifo(DevIndex, 0);
	if (rst < 0) { return rst; }

	// 设置 Ao 0 输出为 无限不循环 模式
	rst = SetAoMode(DevIndex, 0, 2);
	if (rst < 0) { return rst; }

	// 设置 Ao 0 输出采样率
	// 此处设置为 100000ns，即 10kS/s
	rst = SetAoSamplePeriod(DevIndex, 0, 100000);
	if (rst < 0) { return rst; }

	// 设置 Ao 0 触发源，Ao 0 软件触发
	rst = SetAoTrigSource(DevIndex, 0, 2);
	if (rst < 0) { return rst; }

	// 先发送 1000 点波形数据到硬件中
	for (i = 0; i < 1000; i++)
	{
		WaveData = rand()/(float(RAND_MAX));
		rst = SetAoFifo(DevIndex, 0, WaveData);
		if (rst < 0) { return rst; }
	}

	// 设置 Ao 准备完成，AoReady
	rst = AoReady(DevIndex, 0, 1);
	if (rst < 0) { return rst; }

	// 发出 Ao 0 软件触发命令
	rst = SetAoSoftTrig(DevIndex, 0);
	if (rst < 0) { return rst; }

	// 开始发送不循环的波形数据到硬件
	// 此处仅发送 10 次作为范例
	for (i = 0; i < 10; i++)
	{
		// 再发送 1000 点波形数据到硬件中
		for (j = 0; j < 1000; j++)
		{
			WaveData = rand() / (float(RAND_MAX));
			rst = SetAoFifo(DevIndex, 0, WaveData);
			if (rst < 0) { return rst; }
		}

		// 每隔 100ms 发送 1000 点波形数据到硬件中
		// 保证硬件 FIFO 中有足够的数据，但又不溢出
		Sleep(100);
	}

	printf("press any key + Enger to quit.\n");
	scanf_s("%d", &i);

	// 清除 Ao 0 软件触发标志
	rst = ClearAoSoftTrig(DevIndex, 0);
	if (rst < 0) { return rst; }

	// 清除 Ao 0 准备完成标志
	rst = AoReady(DevIndex, 0, 0);
	if (rst < 0) { return rst; }

	// 关闭设备
	rst = CloseDevice(DevIndex);

	return rst;
}

// 运行程序: Ctrl + F5 或调试 >“开始执行(不调试)”菜单
// 调试程序: F5 或调试 >“开始调试”菜单

// 入门提示: 
//   1. 使用解决方案资源管理器窗口添加/管理文件
//   2. 使用团队资源管理器窗口连接到源代码管理
//   3. 使用输出窗口查看生成输出和其他消息
//   4. 使用错误列表窗口查看错误
//   5. 转到“项目”>“添加新项”以创建新的代码文件，或转到“项目”>“添加现有项”以将现有代码文件添加到项目
//   6. 将来，若要再次打开此项目，请转到“文件”>“打开”>“项目”并选择 .sln 文件
